pub fn tokenize(input: &str) -> Result<Vec<ShellToken>>Expand description
Tokenize a shell command string into tokens, respecting quoting rules.
Returns Err if quotes are unbalanced.
pub fn tokenize(input: &str) -> Result<Vec<ShellToken>>Tokenize a shell command string into tokens, respecting quoting rules.
Returns Err if quotes are unbalanced.