Module delegate
agentzero_
tools
0.3.0
Module delegate
Module Items
Structs
Type Aliases
In crate agentzero_
tools
agentzero_tools
Module
delegate
Structs

Delegate
Tool
Type Aliases

Tool
Builder
Function that builds a tool set for sub-agents. The delegate tool calls this when running in agentic mode, then filters the result based on each agent’s
allowed_tools
configuration.